==> kabaret.gui-0.0.0a3.zip: kabaret.gui-0.0.0a3/setup.py <==

import sys
from setuptools import setup

# use the version of the framework package as the base version:
try:
    import kabaret.version
except ImportError:
    version = '0.0.0a1'
else:
    version = kabaret.version.get()


if not hasattr(sys, 'version_info') or sys.version_info < (2, 6, 0, 'final'):
    raise SystemExit("Kabaret requires Python 2.6 or later.")

install_requires = ['kabaret', 'kabaret.core']

setup(
    name='kabaret.gui',
    namespace_packages=['kabaret'],
    packages=[
        'kabaret',
        'kabaret.gui', 
        'kabaret.gui.icons', 
        'kabaret.gui.standalone', 
        'kabaret.gui.styles', 
            'kabaret.gui.styles.dark', 
        'kabaret.gui.widgets', 
    ],
    version=version,
    install_requires=install_requires,
    description='Qt based GUI package for the kabaret framework.',
    url='http://packages.python.org/kabaret',
    author='Damien Coureau',
    author_email='dee@dee909.com',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        
        'Topic :: Office/Business :: Groupware',
        'Topic :: Office/Business :: Scheduling',
        
        'Intended Audience :: Developers',
        'Intended Audience :: End Users/Desktop',
        
        'Operating System :: OS Independent',
        
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        
        'License :: OSI Approved :: GNU Lesser General Public License v3 or later (LGPLv3+)',
    ],
)

==> kabaret.gui-0.1.0b1.zip: kabaret.gui-0.1.0b1/setup.py <==

import sys
from setuptools import setup

# use the version of the framework package as the base version:
try:
    import kabaret.version
except ImportError:
    version = '0.0.0a1'
else:
    version = kabaret.version.get()


if not hasattr(sys, 'version_info') or sys.version_info < (2, 6, 0, 'final'):
    raise SystemExit("Kabaret requires Python 2.6 or later.")

install_requires = ['kabaret.core']

setup(
    name='kabaret.gui',
    namespace_packages=['kabaret'],
    packages=[
        'kabaret',
        'kabaret.gui', 
        'kabaret.gui.icons', 
        'kabaret.gui.models', 
        'kabaret.gui.standalone', 
        'kabaret.gui.styles', 
        'kabaret.gui.styles.dark', 
        'kabaret.gui.styles.neonative', 
        'kabaret.gui.user_gui', 
        'kabaret.gui.widgets', 
        'kabaret.gui.widgets.value_editor', 
        'kabaret.gui.widgets.value_editor.editors', 
    ],
    include_package_data=True, # needed for icons and style css
    version=version,
    install_requires=install_requires,
    description='Qt based GUI package for the kabaret framework.',
    url='http://packages.python.org/kabaret',
    author='Damien Coureau',
    author_email='dee@dee909.com',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        
        'Topic :: Office/Business :: Groupware',
        'Topic :: Office/Business :: Scheduling',
        
        'Intended Audience :: Developers',
        'Intended Audience :: End Users/Desktop',
        
        'Operating System :: OS Independent',
        
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        
        'License :: OSI Approved :: GNU Lesser General Public License v3 or later (LGPLv3+)',
    ],
)
